``zope.authentication`` README
==============================

.. image:: https://travis-ci.org/zopefoundation/zope.authentication.png?branch=master
        :target: https://travis-ci.org/zopefoundation/zope.authentication

This package provides a definition of authentication concepts for use in
Zope Framework.
